@@ -4,6 +4,7 @@
 package org.torproject.onionoo.updater;
 
 import org.torproject.descriptor.Descriptor;
+import org.torproject.descriptor.DescriptorCollector;
 import org.torproject.onionoo.util.FormattingUtils;
 
 import org.slf4j.Logger;
@@ -22,9 +23,11 @@ public class DescriptorSource {
   private static final Logger log = LoggerFactory.getLogger(
       DescriptorSource.class);
 
-  private final File inRecentDir = new File("in/recent");
+  private final File inDir = new File("in");
 
-  private final File inArchiveDir = new File("in/archive");
+  private final File inRecentDir = new File(inDir, "recent");
+
+  private final File inArchiveDir = new File(inDir, "archive");
 
   private final File statusDir = new File("status");
 
@@ -65,55 +68,40 @@ public class DescriptorSource {
 
   /** Downloads descriptors from CollecTor. */
   public void downloadDescriptors() {
+    List<String> remoteDirectories = new ArrayList<>();
     for (DescriptorType descriptorType : DescriptorType.values()) {
-      log.info("Loading: " + descriptorType);
-      this.downloadDescriptors(descriptorType);
+      remoteDirectories.add("/recent/" + descriptorType.getDir());
     }
-  }
-
-  private int localFilesBefore = 0;
-
-  private int foundRemoteFiles = 0;
-
-  private int downloadedFiles = 0;
-
-  private int deletedLocalFiles = 0;
-
-  private void downloadDescriptors(DescriptorType descriptorType) {
-    DescriptorDownloader descriptorDownloader =
-        new DescriptorDownloader(descriptorType);
-    this.localFilesBefore += descriptorDownloader.statLocalFiles();
-    this.foundRemoteFiles +=
-        descriptorDownloader.fetchRemoteDirectory();
-    this.downloadedFiles += descriptorDownloader.fetchRemoteFiles();
-    this.deletedLocalFiles += descriptorDownloader.deleteOldLocalFiles();
+    DescriptorCollector dc = org.torproject.descriptor.DescriptorSourceFactory
+        .createDescriptorCollector();
+    dc.collectDescriptors("https://collector.torproject.org",
+        remoteDirectories.toArray(new String[0]), 0L, inDir, true);
   }
 
   /** Reads archived and recent descriptors from disk and feeds them into
    * any registered listeners. */
   public void readDescriptors() {
     this.readArchivedDescriptors();
-    log.debug("Reading recent " + DescriptorType.RELAY_SERVER_DESCRIPTORS
-        + " ...");
+    log.debug("Reading recent {} ...", DescriptorType.RELAY_SERVER_DESCRIPTORS);
     this.readDescriptors(DescriptorType.RELAY_SERVER_DESCRIPTORS,
         DescriptorHistory.RELAY_SERVER_HISTORY, true);
-    log.debug("Reading recent " + DescriptorType.RELAY_EXTRA_INFOS + " ...");
+    log.debug("Reading recent {} ...", DescriptorType.RELAY_EXTRA_INFOS);
     this.readDescriptors(DescriptorType.RELAY_EXTRA_INFOS,
         DescriptorHistory.RELAY_EXTRAINFO_HISTORY, true);
-    log.debug("Reading recent " + DescriptorType.EXIT_LISTS + " ...");
+    log.debug("Reading recent {} ...", DescriptorType.EXIT_LISTS);
     this.readDescriptors(DescriptorType.EXIT_LISTS,
         DescriptorHistory.EXIT_LIST_HISTORY, true);
-    log.debug("Reading recent " + DescriptorType.RELAY_CONSENSUSES + " ...");
+    log.debug("Reading recent {} ...", DescriptorType.RELAY_CONSENSUSES);
     this.readDescriptors(DescriptorType.RELAY_CONSENSUSES,
         DescriptorHistory.RELAY_CONSENSUS_HISTORY, true);
-    log.debug("Reading recent " + DescriptorType.BRIDGE_SERVER_DESCRIPTORS
-        + " ...");
+    log.debug("Reading recent {} ...",
+        DescriptorType.BRIDGE_SERVER_DESCRIPTORS);
     this.readDescriptors(DescriptorType.BRIDGE_SERVER_DESCRIPTORS,
         DescriptorHistory.BRIDGE_SERVER_HISTORY, false);
-    log.debug("Reading recent " + DescriptorType.BRIDGE_EXTRA_INFOS + " ...");
+    log.debug("Reading recent {} ...", DescriptorType.BRIDGE_EXTRA_INFOS);
     this.readDescriptors(DescriptorType.BRIDGE_EXTRA_INFOS,
         DescriptorHistory.BRIDGE_EXTRAINFO_HISTORY, false);
-    log.debug("Reading recent " + DescriptorType.BRIDGE_STATUSES + " ...");
+    log.debug("Reading recent {} ...", DescriptorType.BRIDGE_STATUSES);
     this.readDescriptors(DescriptorType.BRIDGE_STATUSES,
         DescriptorHistory.BRIDGE_STATUS_HISTORY, false);
   }
@@ -133,35 +121,7 @@ public class DescriptorSource {
         descriptorListener.processDescriptor(descriptor, relay);
       }
     }
-    switch (descriptorType) {
-      case RELAY_CONSENSUSES:
-        log.info("Read recent relay network consensuses");
-        break;
-      case RELAY_SERVER_DESCRIPTORS:
-        log.info("Read recent relay server descriptors");
-        break;
-      case RELAY_EXTRA_INFOS:
-        log.info("Read recent relay extra-info descriptors");
-        break;
-      case EXIT_LISTS:
-        log.info("Read recent exit lists");
-        break;
-      case BRIDGE_STATUSES:
-        log.info("Read recent bridge network statuses");
-        break;
-      case BRIDGE_SERVER_DESCRIPTORS:
-        log.info("Read recent bridge server descriptors");
-        break;
-      case BRIDGE_EXTRA_INFOS:
-        log.info("Read recent bridge extra-info descriptors");
-        break;
-      default:
-        /* We shouldn't run into this default case, but if we do, it's
-         * because we added a new type to DescriptorType but forgot to
-         * update this switch statement.  It's just logging, so not the
-         * end of the world. */
-        log.info("Read recent descriptors of type " + descriptorType);
-    }
+    log.info("Read recent/{}.", descriptorType.getDir());
   }
 
   /** Reads archived descriptors from disk and feeds them into any
@@ -172,7 +132,9 @@ public class DescriptorSource {
     }
     log.info("Reading archived descriptors...");
     this.archiveDescriptorQueue = new DescriptorQueue(this.inArchiveDir,
-        null, null);
+        null, this.statusDir);
+    this.archiveDescriptorQueue.readHistoryFile(
+        DescriptorHistory.ARCHIVED_HISTORY);
     Descriptor descriptor;
     while ((descriptor = this.archiveDescriptorQueue.nextDescriptor())
         != null) {
@@ -208,15 +170,15 @@ public class DescriptorSource {
       if (descriptorType == null) {
         log.warn("Unrecognized descriptor in "
             + this.inArchiveDir.getAbsolutePath() + " with annotations "
-            + descriptor.getAnnotations() + ".  Not reading any further"
-            + "archived descriptors.");
-        break;
+            + descriptor.getAnnotations() + ".  Skipping descriptor.");
+        continue;
       }
       for (DescriptorListener descriptorListener :
           this.descriptorListeners.get(descriptorType)) {
         descriptorListener.processDescriptor(descriptor, relay);
       }
     }
+    this.archiveDescriptorQueue.writeHistoryFile();
     log.info("Read archived descriptors");
   }
 
@@ -232,16 +194,8 @@ public class DescriptorSource {
    * descriptors during the current execution. */
   public String getStatsString() {
     StringBuilder sb = new StringBuilder();
-    sb.append("    " + this.localFilesBefore + " recent descriptor files "
-        + "found locally\n");
-    sb.append("    " + this.foundRemoteFiles + " recent descriptor files "
-        + "found remotely\n");
-    sb.append("    " + this.downloadedFiles + " recent descriptor files "
-        + "downloaded from remote\n");
-    sb.append("    " + this.deletedLocalFiles + " recent descriptor "
-        + "files deleted locally\n");
-    sb.append("    " + this.descriptorQueues.size() + " descriptor "
-        + "queues created for recent descriptors\n");
+    sb.append("    ").append(this.descriptorQueues.size())
+      .append(" descriptor ").append("queues created for recent descriptors\n");
     int historySizeBefore = 0;
     int historySizeAfter = 0;
     long descriptors = 0L;
@@ -252,23 +206,23 @@ public class DescriptorSource {
       descriptors += descriptorQueue.getReturnedDescriptors();
       bytes += descriptorQueue.getReturnedBytes();
     }
-    sb.append("    " + FormattingUtils.formatDecimalNumber(
-        historySizeBefore) + " recent descriptors excluded from this "
-        + "execution\n");
-    sb.append("    " + FormattingUtils.formatDecimalNumber(descriptors)
-        + " recent descriptors provided\n");
-    sb.append("    " + FormattingUtils.formatBytes(bytes)
-        + " of recent descriptors provided\n");
-    sb.append("    " + FormattingUtils.formatDecimalNumber(
-        historySizeAfter) + " recent descriptors excluded from next "
-        + "execution\n");
+    sb.append("    ").append(FormattingUtils.formatDecimalNumber(
+        historySizeBefore)).append(" recent descriptors excluded from this ")
+        .append("execution\n");
+    sb.append("    ").append(FormattingUtils.formatDecimalNumber(descriptors))
+        .append(" recent descriptors provided\n");
+    sb.append("    ").append(FormattingUtils.formatBytes(bytes))
+        .append(" of recent descriptors provided\n");
+    sb.append("    ").append(FormattingUtils.formatDecimalNumber(
+        historySizeAfter)).append(" recent descriptors excluded from next ")
+        .append("execution\n");
     if (this.archiveDescriptorQueue != null) {
-      sb.append("    " + FormattingUtils.formatDecimalNumber(
-          this.archiveDescriptorQueue.getReturnedDescriptors())
-          + " archived descriptors provided\n");
-      sb.append("    " + FormattingUtils.formatBytes(
-          this.archiveDescriptorQueue.getReturnedBytes()) + " of "
-          + "archived descriptors provided\n");
+      sb.append("    ").append(FormattingUtils.formatDecimalNumber(
+          this.archiveDescriptorQueue.getReturnedDescriptors()))
+        .append(" archived descriptors provided\n");
+      sb.append("    ").append(FormattingUtils.formatBytes(
+          this.archiveDescriptorQueue.getReturnedBytes())).append(" of ")
+        .append("archived descriptors provided\n");
     }
     return sb.toString();
   }
